# MCAP Website

MCAP documentation is built using [Docusaurus](https://docusaurus.io/).

### Installation

```sh
corepack enable
yarn install
```

### Local Development

```sh
yarn start
```

This command starts a local development server and opens up a browser window. Most changes are reflected live without having to restart the server.

### Production Build

```sh
yarn build
```

This command generates static content into the `build` directory and can be served using:

```sh
yarn serve
```

### Deployment

Deployed using GitHub Actions to https://mcap.dev/
